# Filter reference

For filters, the *Receives* field in the function descriptions is used to document what columns are assumed to be in the DriveData objects processed by the filter. 


::: pydre.filters.common
    options:
        show_root_heading: false
        filters: ["!^_"]